import random

from pyranda.okres import Okres

class Okress:
    def __init__(self):
        # Veřejné pole s okresy..
        self.okres = []

        # Středočeský kraj
        self.okres.append(Okres("Benešov", "BN", "Benešov"))
        self.okres.append(Okres("Beroun", "BE", "Beroun"))
        self.okres.append(Okres("Kladno", "KD", "Kladno"))
        self.okres.append(Okres("Kolín", "KO", "Kolín"))
        self.okres.append(Okres("Kutná Hora", "KH", "Kutnái Hora"))
        self.okres.append(Okres("Mělník", "ME", "Mělník"))
        self.okres.append(Okres("Mladá Boleslav", "MB", "Mladá Boleslav"))
        self.okres.append(Okres("Nymburk", "NB", "Nymburk"))
        self.okres.append(Okres("Praha-východ", "PY", "Praha-východ"))
        self.okres.append(Okres("Praha-západ", "PZ", "Praha-západ"))
        self.okres.append(Okres("Příbram", "PB", "Příbram"))
        self.okres.append(Okres("Rakovník", "RA", "Rakovník"))

        # Jihočeský kraj
        self.okres.append(Okres("České Budějovice", "CB", "České Budějovice"))
        self.okres.append(Okres("Český Krumlov", "CK", "Český Krumlov"))
        self.okres.append(Okres("Jindřichův Hradec", "JH", "Jindřichův Hradec"))
        self.okres.append(Okres("Písek", "OI", "Písek"))
        self.okres.append(Okres("Prachatice", "PT", "Prachatice"))
        self.okres.append(Okres("Strakonice", "ST", "Strakonice"))
        self.okres.append(Okres("Tábor", "TA", "Tábor"))

        # Plzeňský kraj
        self.okres.append(Okres("Domažlice", "DO", "Domažlice"))
        self.okres.append(Okres("Klatovy", "KT", "Klatovy"))
        self.okres.append(Okres("Plzeň-jih", "PJ", "Plzeň-jih"))
        self.okres.append(Okres("Plzeň-město", "PM", "Plzeň-město"))
        self.okres.append(Okres("Plzeň-sever", "PS", "Plzeň-sever"))
        self.okres.append(Okres("Rokycany", "RO", "Rokycany"))
        self.okres.append(Okres("Tachov", "TC", "Tachov"))

        # Karlovarský kraj
        self.okres.append(Okres("Cheb", "CH", "Cheb"))
        self.okres.append(Okres("Karlovy Vary", "KV", "Karlovy Vary"))
        self.okres.append(Okres("Sokolov", "SO", "Sokolov"))

       # Ústecký kraj
        self.okres.append(Okres("Děčín", "DC", "Děčín"))
        self.okres.append(Okres("Chomutov", "CV", "Chomutov"))
        self.okres.append(Okres("Litoměřice", "LT", "Litoměřice"))
        self.okres.append(Okres("Louny", "LN", "Louny"))
        self.okres.append(Okres("Most", "MO", "Most"))
        self.okres.append(Okres("Teplice", "TP", "Teplice"))
        self.okres.append(Okres("Ústí nad Labem", "UL", "Ústí nad Labem"))

        # Liberecký kraj
        self.okres.append(Okres("Česká Lípa", "CL", "Česká Lípa"))
        self.okres.append(Okres("Jablonec nad Nisou", "JN", "Jablonec nad Nisou"))
        self.okres.append(Okres("Liberec", "LI", "Liberec"))
        self.okres.append(Okres("Semily", "SM", "Semily"))

        # Královéhradecký kraj
        self.okres.append(Okres("Hradec Králové", "HK", "Hradec Králové"))
        self.okres.append(Okres("Jičín", "JC", "Jičín"))
        self.okres.append(Okres("Náchod", "NA", "Náchod"))
        self.okres.append(Okres("Rychnov nad Kněžnou", "RK", "Rychnov nad Kněžnou"))
        self.okres.append(Okres("Trutnov", "TU", "Trutnov"))

        # Pardubický kraj
        self.okres.append(Okres("Chrudim", "CR", "Chrudim"))
        self.okres.append(Okres("Pardubice", "PU", "Pardubice"))
        self.okres.append(Okres("Svitavy", "SY", "Svitavy"))
        self.okres.append(Okres("Ústí nad Orlicí", "UO", "Ústí nad Orlicí"))

        # Kraj Vysočina
        self.okres.append(Okres("Havlíčkův Brod", "HB", "Havlíčkův Brod"))
        self.okres.append(Okres("Jihlava", "JI", "Jihlava"))
        self.okres.append(Okres("Pelhřimov", "PE", "Pelhřimov"))
        self.okres.append(Okres("Třebíč", "TR", "Třebíč"))
        self.okres.append(Okres("Žďár nad Sázavou", "ZR", "Žďár nad Sázavou"))

        # Jihomoravský kraj
        self.okres.append(Okres("Blansko", "BK", "Blansko"))
        self.okres.append(Okres("Brno-město", "BM", "Brno-město"))
        self.okres.append(Okres("Brno-venkov", "BI", "Brno-venkov"))
        self.okres.append(Okres("Břeclav", "BV", "Břeclav"))
        self.okres.append(Okres("Hodonín", "HO", "Hodonín"))
        self.okres.append(Okres("Vyškov", "VY", "Vyškov"))
        self.okres.append(Okres("Znojmo", "ZN", "Znojmo"))

        # Olomoucký kraj
        self.okres.append(Okres("Jeseník", "JE", "Jeseník"))
        self.okres.append(Okres("Olomouc", "OC", "Olomouc"))
        self.okres.append(Okres("Prostějov", "PV", "Prostějov"))
        self.okres.append(Okres("Přerov", "PR", "Přerov"))
        self.okres.append(Okres("Šumperk", "SU", "Šumperk"))
 
        # Moravskoslezský kraj
        self.okres.append(Okres("Bruntál", "BR", "Bruntál"))
        self.okres.append(Okres("Frýdek-Místek", "FM", "Frýdek-Místek"))
        self.okres.append(Okres("Karviná", "KI", "Karviná"))
        self.okres.append(Okres("Nový Jičín", "NJ", "Nový Jičín"))
        self.okres.append(Okres("Opava", "OP", "Opava"))
        self.okres.append(Okres("Ostrava-město", "OV", "Ostrava-město"))

        # Zlínský kraj
        self.okres.append(Okres("Kroměříž", "KM", "Kroměříž"))
        self.okres.append(Okres("Uherské Hradiště", "UH", "Uherské Hradiště"))
        self.okres.append(Okres("Vsetín", "VS", "Vsetín"))
        self.okres.append(Okres("Zlín", "ZL", "Zlín"))



import random

from pyranda.kraj import Kraj
from pyranda.okres import Okres

class Krajs:
    """ Objekt obsahující jednotlivé kraje v ČR.. """
    def __init__(self):
        self.kraj = []
        self.kraj.append(Kraj("Hlavní město Praha", "PHA", "Praha"))
        self.kraj.append(Kraj("Středočeský kraj",  "STČ", "Praha"))
        self.kraj.append(Kraj("Jihočeský kraj", "KJČ", "České Budějovice"))
        self.kraj.append(Kraj("Plzeňský kraj",  "KPL", "Plzeň"))
        self.kraj.append(Kraj("Karlovarský kraj", "KVK", "Karlovy Vary"))
        self.kraj.append(Kraj("Ústecký kraj", "KUL", "Ústí nad Labem"))
        self.kraj.append(Kraj("Liberecký kraj",  "KLB", "Liberec"))
        self.kraj.append(Kraj("Královéhradecký kraj", "KHK", "Hradec Králové"))
        self.kraj.append(Kraj("Pardubický kraj", "KPA", "Pardubice"))
        self.kraj.append(Kraj("Olomoucký kraj", "KOL", "Olomouc"))
        self.kraj.append(Kraj("Moravskoslezský kraj", "MSK", "Ostrava"))
        self.kraj.append(Kraj("Jihomoravský kraj", "JMK", "Brno"))
        self.kraj.append(Kraj("Zlínský kraj", "ZLK", "Zlín"))
        self.kraj.append(Kraj("Kraj Vysočina", "VYS", "Jihlava"))

    def getNazev(self, oznaceni):
        """ Předání názvu krajs z jeho označení.. """
        for item in self.kraj:
            if item.oznaceni == oznaceni:
                return item.nazev
        return "N/A"

    def getMesto(self, oznaceni):
        """ Předání názvu krajského města podle označení krajs.. """
        for item in self.kraj:
            if item.oznaceni == oznaceni:
                return item.mesto
        return "N/A"


def getRandomKraj():
    """ Předá náhodný kraj jako objekt.. """
    krajs = Krajs()
    index = random.randint(0, len(krajs.kraj)-1)
    return krajs.kraj[index]


def list_kraj():
    """ Zobrazení všech krajů.. """
    print()
    print("Výpsání všech krajů")
    print("-------------------")
    krajs = Krajs()
    for kraj in krajs.kraj:
        print(kraj.nazev)

    print()
    print("Výpsání náhodných krajů")
    print("-----------------------")
    for i in range(0,20):
        kraj = getRandomKraj()
        print(kraj.nazev + ", " + kraj.oznaceni + ", " + kraj.mesto)



import random

class Mesic:
    """ Třída zapouzdřující chování měsíce.. """
    def __init__(self):
        self.mesice = ('leden', 'únor', 'březen', 'duben', 'květen', 'červen', 'červenec', 'srpen', 'září', 'říjen', 'listopad', 'prosinec')
        self.nazev = ""
        self.cislo = 0

    def SetMesic(self, cislo):
        self.cislo = cislo
        self.nazev = self.mesice[cislo-1]

    def SetRandom(self):
        i = random.randint(1, 12)
        self.SetMesic(i)

def GetRandomMesicNazev():
    """ Předej mi náhodný název měsíce.. """
    m = Mesic()
    m.SetRandom()
    return m.nazev

def GetRandomMesicCislo():
    """ Předej mi náhodné číslo měsíce.. """
    m = Mesic()
    m.SetRandom()
    return m.cislo



class Mesto:
    """Objekt pro zapouzdření informací o městě, obecně obci.."""
    def __init__(self, nazev, oznaceni):
        self.nazev = nazev
        self.oznaceni = oznaceni

    def IsEqual(self, mesto):
        """ Porovnáme dva mesto a pokud jsou schodné vracíme True.. """
        if self.nazev == mesto.nazev and self.oznaceni == mesto.oznaceni:
            return True
        return False


mestos = []
mestos.append(Mesto("Praha", "AA"))
mestos.append(Mesto("Brno", "BI"))
mestos.append(Mesto("Ostrava", "OS"))
mestos.append(Mesto("Plzeň", "PL"))
mestos.append(Mesto("Liberec", "LI"))
mestos.append(Mesto("Olomouc", "OC"))
mestos.append(Mesto("České Budějovice", "ČB"))
mestos.append(Mesto("Ústí nad Labem", "ÚL"))
mestos.append(Mesto("Hradec Králov", "HK"))
mestos.append(Mesto("Pardubice", "PA"))
mestos.append(Mesto("Zlín", "ZL"))
mestos.append(Mesto("Havířov", "HA"))
mestos.append(Mesto("Kladno", "KL"))
mestos.append(Mesto("Most", "MO"))
mestos.append(Mesto("Opava", "OP"))
mestos.append(Mesto("Frýdek-Místek", "FM"))
mestos.append(Mesto("Karviná", "KA"))
mestos.append(Mesto("Jihlava", "JI"))
mestos.append(Mesto("Teplice", "TE"))
mestos.append(Mesto("Děčín", "DE"))
mestos.append(Mesto("Karlovy Vary", "KV"))
mestos.append(Mesto("Chomutov", "CH"))
mestos.append(Mesto("Jablonec nad Nisou", "JN"))
mestos.append(Mesto("Prostějov", "PJ"))
mestos.append(Mesto("Přerov", "PŘ"))
mestos.append(Mesto("Mladá Boleslav", "MB"))
mestos.append(Mesto("Třebíš", "TŘ"))
mestos.append(Mesto("Česká Lípa", "ČL"))
mestos.append(Mesto("Třinec", "TŘ"))
mestos.append(Mesto("Tábor", "TÁ"))
mestos.append(Mesto("Znojmo", "ZN"))
mestos.append(Mesto("Příbram", "PŘ"))
mestos.append(Mesto("Cheb", "CE"))
mestos.append(Mesto("Orlová", "OR"))
mestos.append(Mesto("Kolín", "KO"))
mestos.append(Mesto("Trutnov", "TR"))
mestos.append(Mesto("Písek", "PÍ"))
mestos.append(Mesto("Kroměříž", "KM"))
mestos.append(Mesto("Šumperk", "ŠU"))
mestos.append(Mesto("Vsetín", "VS"))
mestos.append(Mesto("Valašské Meziříčí", "VM"))
mestos.append(Mesto("Litvínov", "LI"))
mestos.append(Mesto("Uherské Hradiště", "UH"))
mestos.append(Mesto("Hodnotnín", "HO"))
mestos.append(Mesto("Český Těšín", "ČT"))
mestos.append(Mesto("Břeclav", "BŘ"))
mestos.append(Mesto("Krnov", "KR"))
mestos.append(Mesto("Litoměřice", "LI"))
mestos.append(Mesto("Sokolov", "SO"))
mestos.append(Mesto("Nový Jičín", "NJ"))
mestos.append(Mesto("Havlíčkův Brod", "HB"))
mestos.append(Mesto("Chrudim", "CU"))
mestos.append(Mesto("Strakonice", "ST"))
mestos.append(Mesto("Kopřivnice", "KO"))
mestos.append(Mesto("Klatovy", "KL"))
mestos.append(Mesto("Žďár nad Sázavou", "ŽS"))
mestos.append(Mesto("Bohumín", "BO"))
mestos.append(Mesto("Jindřichův Hradec", "JH"))
mestos.append(Mesto("Vyškov", "VY"))
mestos.append(Mesto("Blansko", "BL"))
mestos.append(Mesto("Kutná Hora", "KH"))
mestos.append(Mesto("Náchod", "NÁ"))
mestos.append(Mesto("Jirkov", "JI"))
mestos.append(Mesto("Mělník", "MĚ"))
mestos.append(Mesto("Žatec", "ŽA"))
mestos.append(Mesto("Hranice", "HR"))
mestos.append(Mesto("Beroun", "BE"))
mestos.append(Mesto("Louny", "LO"))
mestos.append(Mesto("Otrokovice", "OT"))
mestos.append(Mesto("Kralupy nad Vltavou", "KV"))
mestos.append(Mesto("Kadaň", "KA"))
mestos.append(Mesto("Brandýs nad Laběm", "BL"))
mestos.append(Mesto("Ostrov", "OS"))
mestos.append(Mesto("Svitavy", "SV"))
mestos.append(Mesto("Bruntál", "BR"))
mestos.append(Mesto("Uherský Brod", "UB"))
mestos.append(Mesto("Rožnov pod Radhošťem", "RK"))
mestos.append(Mesto("Jičín", "JI"))
mestos.append(Mesto("Rakovník", "RA"))
mestos.append(Mesto("Neratovice", "NE"))
mestos.append(Mesto("Benešov", "BE"))
mestos.append(Mesto("Pelhřimov", "PE"))
mestos.append(Mesto("Dvůr Králové nad Labem", "DK"))
mestos.append(Mesto("Bilina", "BI"))
mestos.append(Mesto("Varnsdorf", "VA"))
mestos.append(Mesto("Slaný", "SL"))
mestos.append(Mesto("Klášterec nad Ohří", "KO"))
mestos.append(Mesto("Mariánské Lázně", "ML"))
mestos.append(Mesto("Nymburk", "NY"))
mestos.append(Mesto("Ústí nad Orlicí", "ÚO"))
mestos.append(Mesto("Turnov", "TU"))
mestos.append(Mesto("Chodov", "CV"))
mestos.append(Mesto("Rokycany", "RO"))
mestos.append(Mesto("Hlučín", "KHL"))
mestos.append(Mesto("Poděbrady", "PO"))
mestos.append(Mesto("Zábřeh", "ZÁ"))
mestos.append(Mesto("Šternberk", "ŠT"))
mestos.append(Mesto("Krupka", "KR"))
mestos.append(Mesto("Říčany", "ŘÍ"))
mestos.append(Mesto("Český Krumlov", "ČK"))
mestos.append(Mesto("Roudnice nad Labem", "RL"))
mestos.append(Mesto("Aš", "AŠ"))
mestos.append(Mesto("Tachov", "TA"))
mestos.append(Mesto("Vrchlabí", "VR"))
mestos.append(Mesto("Jaroměř", "JA"))
mestos.append(Mesto("Vysoké Mýto", "VM"))
mestos.append(Mesto("Nový Bor", "NB"))
mestos.append(Mesto("Holešov", "HO"))
mestos.append(Mesto("Vlašim", "VL"))
mestos.append(Mesto("Uničov", "UN"))
mestos.append(Mesto("Jeseník", "JE"))
mestos.append(Mesto("Velké Meziříčí", "VM"))
mestos.append(Mesto("Čelákovce", "ČE"))
mestos.append(Mesto("Kyjov", "KY"))
mestos.append(Mesto("Veselí nad Moravou", "VÍ"))
mestos.append(Mesto("Boskovice", "BO"))
mestos.append(Mesto("Prachatice", "PE"))
mestos.append(Mesto("Rychnov nad Kněžnou", "RK"))
mestos.append(Mesto("Sušice", "SU"))
mestos.append(Mesto("Rumburk", "RU"))
mestos.append(Mesto("Domažlice", "DO"))
mestos.append(Mesto("Frenštát pod Radhoštěm", "FR"))
mestos.append(Mesto("Humpolec", "HU"))
mestos.append(Mesto("Kuřim", "KU"))
mestos.append(Mesto("Moravská Třebová", "MT"))
mestos.append(Mesto("Nové Město na Moravě", "NM"))
mestos.append(Mesto("Litomyšl", "LI"))
mestos.append(Mesto("Lanškroun", "LA"))
mestos.append(Mesto("Čáslav", "ČA"))
mestos.append(Mesto("Hlinsko", "HL"))
mestos.append(Mesto("Litovel", "LI"))
mestos.append(Mesto("Nové Město nad Metují", "NM"))
mestos.append(Mesto("Frýdlant nad Ostravicí", "FO"))
mestos.append(Mesto("Milovice", "MI"))
mestos.append(Mesto("Mohelnice", "MO"))
mestos.append(Mesto("Ivančice", "IV"))
mestos.append(Mesto("Chotěboř", "CŘ"))
mestos.append(Mesto("Nová Paka", "NP"))
mestos.append(Mesto("Přelouč", "PŘ"))
mestos.append(Mesto("Štětí", "ŠT"))
mestos.append(Mesto("Polička", "PO"))
mestos.append(Mesto("Hořice", "HO"))
mestos.append(Mesto("Choceň", "OC"))
mestos.append(Mesto("Lovosice", "LO"))
mestos.append(Mesto("Milevsko", "MI"))
mestos.append(Mesto("Lysá nad Labem", "LL"))
mestos.append(Mesto("Semily", "SE"))
mestos.append(Mesto("Duchov", "DU"))
mestos.append(Mesto("Příbor", "PŘ"))
mestos.append(Mesto("Tišnov", "TI"))
mestos.append(Mesto("Třeboň", "TŘ"))
mestos.append(Mesto("Dobříč", "DO"))
mestos.append(Mesto("Rýmařov", "RÝ"))
mestos.append(Mesto("Bystřice nad Pernštejnem", "BP"))
mestos.append(Mesto("Červený Kostelec", "ČK"))
mestos.append(Mesto("Bystřice pod Hostýnem", "BH"))
mestos.append(Mesto("Nejdek", "NE"))
mestos.append(Mesto("Mnichovo Hradiště", "MH"))
mestos.append(Mesto("Lipník nad Bečvou", "LB"))
mestos.append(Mesto("Týn nad Vltavou", "TV"))
mestos.append(Mesto("Dubí", "DU"))
mestos.append(Mesto("Stříbro", "ST"))
mestos.append(Mesto("Broumov", "BR"))
mestos.append(Mesto("Roztoky", "RO"))
mestos.append(Mesto("Vimperk", "VI"))




from pyranda.okres import Okres
from pyranda.okress import Okress
from pyranda.kraj import Kraj
from pyranda.krajs import Krajs, getRandomKraj, list_kraj
from pyranda.jmeno import Jmeno
from pyranda.jmenos import Jmenos
from pyranda.osoba import Osoba
from pyranda.prijmeni import Prijmeni
from pyranda.prijmenis import Prijmenis
from pyranda.zeme  import Zeme
from pyranda.mesto import Mesto



class Osoba:
    """Objekt pro zapouzdření informací o osobě.."""
    def __init__(self, nazev, prijmeni, dnar):
        self.nazev = nazev
        self.prijmeni = prijmeni
        self.dnar = dnar

    def IsEqual(self, osoba):
        """ Porovnáme dva osoby a pokud jsou schodné vracíme True.. """
        if self.nazev == osoba.nazev and self.prijmeni == osoba.prijmeni and self.dnar == osoba.dnar:
            return True
        return False



import random

from pyranda.okres import Okres

class Kraj:
    """Objekt pro zapouzdření informací o kraji jako územním celku.."""
    def __init__(self, nazev, oznaceni, mesto):
        self.nazev = nazev
        self.oznaceni = oznaceni
        self.mesto = mesto
        self.okress = []

    def addOkres(self, okres):
        """ Každý kraj může obsahovat jeden anebo více okresů.. """
        self.okress.append(okres)

    def hasOkres(self, okres):
        """ Je námi definovaný okres součístí tohoto kraje? """
        for item in self.okress:
            if item.IsEqual(okres):
                return True
        return False



import random

from pyranda.prijmeni import Prijmeni

class Prijmenis:
    """ Třída zapouzdřující chování obyčejného příjmení.. """
    def __init__(self):
        self.prijmenis = []
        self.dataInit()

    def GetRandomPrijmeni(self, pohlavi):
        index = random.randint(0, len(self.prijmenis) - 1)
        prijmeni= self.prijmenis[index]
        if pohlavi == 2:
            return prijmeni.nazev2 
        return prijmeni.nazev 

    def dataInit(self):
        self.prijmenis.append(Prijmeni("Novák", "Nováková")) 
        self.prijmenis.append(Prijmeni("Koudelka", "Koudelková")) 
        self.prijmenis.append(Prijmeni("Procházka", "Procházková")) 
        self.prijmenis.append(Prijmeni('Adamčík', 'Adamčíková'))
        self.prijmenis.append(Prijmeni('Adámek', 'Adámková'))
        self.prijmenis.append(Prijmeni('Adrián', 'Adriánová'))
        self.prijmenis.append(Prijmeni('Aizner', 'Aiznerová'))
        self.prijmenis.append(Prijmeni('Antalík', 'Antalíková'))
        self.prijmenis.append(Prijmeni('Antl', 'Antlová'))
        self.prijmenis.append(Prijmeni('Antončík', 'Antončíková'))
        self.prijmenis.append(Prijmeni('Antošík', 'Antošíková'))
        self.prijmenis.append(Prijmeni('Apolenář', 'Apolenářová'))
        self.prijmenis.append(Prijmeni('Astaloš', 'Astalošová'))
        self.prijmenis.append(Prijmeni('Ašenbryl', 'Ašenbrylová'))
        self.prijmenis.append(Prijmeni('Augustýn', 'Augustýnková'))
        self.prijmenis.append(Prijmeni('Bednář', 'Bednářová'))
        self.prijmenis.append(Prijmeni('Bubák', 'Bubáková'))
        self.prijmenis.append(Prijmeni('Babčák', 'Babčáková'))
        self.prijmenis.append(Prijmeni('Babin', 'Babincová'))
        self.prijmenis.append(Prijmeni('Bábor', 'Báborová'))
        self.prijmenis.append(Prijmeni('Babuka', 'Babuková'))
        self.prijmenis.append(Prijmeni('Badura', 'Badurová'))
        self.prijmenis.append(Prijmeni('Bachel', 'Bachelová'))
        self.prijmenis.append(Prijmeni('Bachman', 'Bachmannová'))
        self.prijmenis.append(Prijmeni('Bednařík', 'Bednaříková'))
        self.prijmenis.append(Prijmeni('Balada', 'Baladová'))
        self.prijmenis.append(Prijmeni('Balarin', 'Balarinová'))
        self.prijmenis.append(Prijmeni('Balatka', 'Balatková'))
        self.prijmenis.append(Prijmeni('Balcar', 'Balcarová'))
        self.prijmenis.append(Prijmeni('Balcarek', 'Balcarková'))
        self.prijmenis.append(Prijmeni('Bleša', 'Blešová'))
        self.prijmenis.append(Prijmeni('Baltair', 'Baltairová'))
        self.prijmenis.append(Prijmeni('Balvín', 'Balvínová'))
        self.prijmenis.append(Prijmeni('Caban', 'Cabanová'))
        self.prijmenis.append(Prijmeni('Cabuk', 'Cabuková'))
        self.prijmenis.append(Prijmeni('Cahlík', 'Cahlíková'))
        self.prijmenis.append(Prijmeni('Cakl', 'Caklová'))
        self.prijmenis.append(Prijmeni('Calta', 'Caltová'))
        self.prijmenis.append(Prijmeni('Cápík', 'Cápíková'))
        self.prijmenis.append(Prijmeni('Cardal', 'Cardalová'))
        self.prijmenis.append(Prijmeni('Cejhon', 'Cejhonová'))
        self.prijmenis.append(Prijmeni('Cekl', 'Ceklová'))
        self.prijmenis.append(Prijmeni('Celerin', 'Celerinová'))
        self.prijmenis.append(Prijmeni('Černý', 'Černá'))
        self.prijmenis.append(Prijmeni('Cibulka', 'Cibulková'))
        self.prijmenis.append(Prijmeni('Cidlík', 'Cidlíková'))
        self.prijmenis.append(Prijmeni('Císař', 'Císařová'))
        self.prijmenis.append(Prijmeni('Cigler', 'Ciglerová'))
        self.prijmenis.append(Prijmeni('Cichra', 'Cichrová'))
        self.prijmenis.append(Prijmeni('Cikl', 'Ciková'))
        self.prijmenis.append(Prijmeni('Ciprys', 'Ciprysová'))
        self.prijmenis.append(Prijmeni('Čagánek', 'Čagánková'))
        self.prijmenis.append(Prijmeni('Čapek', 'Čapková'))
        self.prijmenis.append(Prijmeni('Čapla', 'Čaplová'))
        self.prijmenis.append(Prijmeni('Černý', 'Černocká'))
        self.prijmenis.append(Prijmeni('Částka', 'Částková'))
        self.prijmenis.append(Prijmeni('Čavajda', 'Čavajdová'))
        self.prijmenis.append(Prijmeni('Čechal', 'Čechalová'))
        self.prijmenis.append(Prijmeni('Čepelík', 'Čepelíková'))
        self.prijmenis.append(Prijmeni('Červenka', 'Červenková'))
        self.prijmenis.append(Prijmeni('Černošek', 'Černošková'))
        self.prijmenis.append(Prijmeni('Červík', 'Červíková'))
        self.prijmenis.append(Prijmeni('Česák', 'Česáková'))
        self.prijmenis.append(Prijmeni('Češek', 'Češková'))
        self.prijmenis.append(Prijmeni('Češka', 'Češková'))
        self.prijmenis.append(Prijmeni('Čičela', 'Čičelová'))
        self.prijmenis.append(Prijmeni('Čokina', 'Čokinová'))
        self.prijmenis.append(Prijmeni('Čtvrtníček', 'Čtvrtníčková'))
        self.prijmenis.append(Prijmeni('Čubák', 'Čubáková'))
        self.prijmenis.append(Prijmeni('Čunek', 'Čunková'))
        self.prijmenis.append(Prijmeni('Cuřín', 'Cuřínová'))
        self.prijmenis.append(Prijmeni('Dratva', 'Dratvová'))
        self.prijmenis.append(Prijmeni('Dajka', 'Dajkvá'))
        self.prijmenis.append(Prijmeni('Dalibor', 'Daliborová'))
        self.prijmenis.append(Prijmeni('Damaška', 'Damašková'))
        self.prijmenis.append(Prijmeni('Dančák', 'Dančáková'))
        self.prijmenis.append(Prijmeni('Dandel', 'Dandelová'))
        self.prijmenis.append(Prijmeni('Danihel', 'Danihelková'))
        self.prijmenis.append(Prijmeni('Danko', 'Danková'))
        self.prijmenis.append(Prijmeni('Daráš', 'Darášová'))
        self.prijmenis.append(Prijmeni('Drábek', 'Drábková'))
        self.prijmenis.append(Prijmeni('Darebník', 'Derebníková'))
        self.prijmenis.append(Prijmeni('Darebníček', 'Darebníčková'))
        self.prijmenis.append(Prijmeni('Drtikol', 'Drtikolová'))
        self.prijmenis.append(Prijmeni('Drásal', 'Drásalová'))
        self.prijmenis.append(Prijmeni('David', 'Davidová'))
        self.prijmenis.append(Prijmeni('Dědek', 'Dětková'))
        self.prijmenis.append(Prijmeni('Dedek', 'Dedková'))
        self.prijmenis.append(Prijmeni('Didov', 'Didová'))
        self.prijmenis.append(Prijmeni('Dikoras', 'Dikorasová'))
        self.prijmenis.append(Prijmeni('Ditrich', 'Ditrichová'))
        self.prijmenis.append(Prijmeni('Djakov', 'Djakovová'))
        self.prijmenis.append(Prijmeni('Dlouhý', 'Dlouhá'))
        self.prijmenis.append(Prijmeni('Dobenčák', 'Dobenčáková'))
        self.prijmenis.append(Prijmeni('Dobrovský', 'Dobrovská'))
        self.prijmenis.append(Prijmeni('Dobřický', 'Dobřická'))
        self.prijmenis.append(Prijmeni('Dočekal', 'Dočekalová'))
        self.prijmenis.append(Prijmeni('Dohnalík', 'Dohnalíková'))
        self.prijmenis.append(Prijmeni('Donutil', 'Donutilová'))
        self.prijmenis.append(Prijmeni('Dokoupil', 'Dokoupilová'))
        self.prijmenis.append(Prijmeni('Domanín', 'Domanínová'))
        self.prijmenis.append(Prijmeni('Donáth', 'Donáthová'))

    def PrintAll():
        for prijmeni in self.prijmenis:
            print(prijmeni.nazev)



from pyranda import Jmenos, Prijmenis

j = pyranda.Jmenos()
p = pyranda.Prijmenis()
for a in range(1, 10):
    jmeno = j.GetRandomJmeno(pohlavi=1)
    prijmeni = p.GetRandomPrijmeni(pohlavi=1)

    print(jmeno + " " + prijmeni)



import random

from pyranda.jmeno import Jmeno

class Jmenos:
    """ Třída zapouzdřující chování obyčejného jména.. """
    def __init__(self):
        self.jmenos1 = []
        self.jmenos2 = []
        self.dataInit()

    def GetRandomJmeno(self, pohlavi):
        if pohlavi == 1:
            index = random.randint(0, len(self.jmenos1) - 1)
            return self.jmenos1[index].nazev;
        if pohlavi == 2:
            index = random.randint(0, len(self.jmenos2) - 1)
            return self.jmenos2[index].nazev;
        return ""

    def dataInit(self):
        self.jmenos1.append(Jmeno("Aleš", 1, []))
        self.jmenos1.append(Jmeno("Alexandr", 1, []))
        self.jmenos1.append(Jmeno("Alois", 1, []))
        self.jmenos1.append(Jmeno("Antonín", 1, []))
        self.jmenos1.append(Jmeno("Bohdan", 1, []))
        self.jmenos1.append(Jmeno("Bohumil", 1, []))
        self.jmenos1.append(Jmeno("Boris", 1, []))
        self.jmenos1.append(Jmeno("Božřivoj", 1, []))
        self.jmenos1.append(Jmeno("Bronislav", 1, []))
        self.jmenos1.append(Jmeno("Ctibor", 1, []))
        self.jmenos1.append(Jmeno("Ctirad", 1, []))
        self.jmenos1.append(Jmeno("Cyril", 1, []))
        self.jmenos1.append(Jmeno("Čeněk", 1, []))
        self.jmenos1.append(Jmeno("Čestmír", 1, []))
        self.jmenos1.append(Jmeno("Dalibor", 1, []))
        self.jmenos1.append(Jmeno("Dan", 1, []))
        self.jmenos1.append(Jmeno("Daniel", 1, []))
        self.jmenos1.append(Jmeno("David", 1, []))
        self.jmenos1.append(Jmeno("Eduard", 1, []))
        self.jmenos1.append(Jmeno("Emil", 1, []))
        self.jmenos1.append(Jmeno("Erik", 1, []))
        self.jmenos1.append(Jmeno("Filip", 1, []))
        self.jmenos1.append(Jmeno("František", 1, []))
        self.jmenos1.append(Jmeno("Gregor", 1, []))
        self.jmenos1.append(Jmeno("Gustav", 1, []))
        self.jmenos1.append(Jmeno("Herbert", 1, []))
        self.jmenos1.append(Jmeno("Hubert", 1, []))
        self.jmenos1.append(Jmeno("Hynek", 1, []))
        self.jmenos1.append(Jmeno("Igor", 1, []))
        self.jmenos1.append(Jmeno("Ivana", 1, []))
        self.jmenos1.append(Jmeno("Ivoš", 1, []))
        self.jmenos1.append(Jmeno("Jakub", 1, []))
        self.jmenos1.append(Jmeno("Jan", 1, []))
        self.jmenos1.append(Jmeno("Jaroslav", 1, []))
        self.jmenos1.append(Jmeno("Jindřich", 1, []))
        self.jmenos1.append(Jmeno("Jiří", 1, []))
        self.jmenos1.append(Jmeno("Jonáš", 1, []))
        self.jmenos1.append(Jmeno("Josef", 1, ["Pepa"]))
        self.jmenos1.append(Jmeno("Kamil", 1, []))
        self.jmenos1.append(Jmeno("Karel", 1, []))
        self.jmenos1.append(Jmeno("Karel", 1, []))
        self.jmenos1.append(Jmeno("Krištof", 1, []))
        self.jmenos1.append(Jmeno("Květoslav", 1, []))
        self.jmenos1.append(Jmeno("Ladislav", 1, []))
        self.jmenos1.append(Jmeno("Leopold", 1, []))
        self.jmenos1.append(Jmeno("Leoš", 1, []))
        self.jmenos1.append(Jmeno("Libor", 1, []))
        self.jmenos1.append(Jmeno("Lubomír", 1, []))
        self.jmenos1.append(Jmeno("Luboš", 1, []))
        self.jmenos1.append(Jmeno("Lukáš", 1, []))
        self.jmenos1.append(Jmeno("Marcel", 1, []))
        self.jmenos1.append(Jmeno("Marek", 1, []))
        self.jmenos1.append(Jmeno("Martin", 1, []))
        self.jmenos1.append(Jmeno("Matěj", 1, []))
        self.jmenos1.append(Jmeno("Matouš", 1, []))
        self.jmenos1.append(Jmeno("Metoděj", 1, []))
        self.jmenos1.append(Jmeno("Michael", 1, []))
        self.jmenos1.append(Jmeno("Mikuláš", 1, []))
        self.jmenos1.append(Jmeno("Milan", 1, []))
        self.jmenos1.append(Jmeno("Miloslav", 1, []))
        self.jmenos1.append(Jmeno("Miloš", 1, []))
        self.jmenos1.append(Jmeno("Mirek", 1, []))
        self.jmenos1.append(Jmeno("Miroslav", 1, []))
        self.jmenos1.append(Jmeno("Mojmír", 1, []))
        self.jmenos1.append(Jmeno("Nikolas", 1, []))
        self.jmenos1.append(Jmeno("Oldřich", 1, []))
        self.jmenos1.append(Jmeno("Oliver", 1, []))
        self.jmenos1.append(Jmeno("Ondřej", 1, []))
        self.jmenos1.append(Jmeno("Oskar", 1, []))
        self.jmenos1.append(Jmeno("Otakar", 1, []))
        self.jmenos1.append(Jmeno("Otto", 1, []))
        self.jmenos1.append(Jmeno("Patrik", 1, []))
        self.jmenos1.append(Jmeno("Pavel", 1, []))
        self.jmenos1.append(Jmeno("Petr", 1, []))
        self.jmenos1.append(Jmeno("Prokop", 1, []))
        self.jmenos1.append(Jmeno("Přemysl", 1, []))
        self.jmenos1.append(Jmeno("Radek", 1, []))
        self.jmenos1.append(Jmeno("Radim", 1, []))
        self.jmenos1.append(Jmeno("Radomír", 1, []))
        self.jmenos1.append(Jmeno("Radovan", 1, []))
        self.jmenos1.append(Jmeno("René", 1, []))
        self.jmenos1.append(Jmeno("Richard", 1, []))
        self.jmenos1.append(Jmeno("Robert", 1, []))
        self.jmenos1.append(Jmeno("Robin", 1, []))
        self.jmenos1.append(Jmeno("Roman", 1, []))
        self.jmenos1.append(Jmeno("Řehoř", 1, []))
        self.jmenos1.append(Jmeno("Samuel", 1, []))
        self.jmenos1.append(Jmeno("Servác", 1, []))
        self.jmenos1.append(Jmeno("Simon", 1, []))
        self.jmenos1.append(Jmeno("Soběslav", 1, []))
        self.jmenos1.append(Jmeno("Stanislav", 1, []))
        self.jmenos1.append(Jmeno("Svatopluk", 1, []))
        self.jmenos1.append(Jmeno("Sylvestr", 1, []))
        self.jmenos1.append(Jmeno("Šimon", 1, []))
        self.jmenos1.append(Jmeno("Štefan", 1, []))
        self.jmenos1.append(Jmeno("Štěpán", 1, []))
        self.jmenos1.append(Jmeno("Tadeáš", 1, []))
        self.jmenos1.append(Jmeno("Tibor", 1, []))
        self.jmenos1.append(Jmeno("Tom", 1, []))
        self.jmenos1.append(Jmeno("Tomáš", 1, []))
        self.jmenos1.append(Jmeno("Tomáš", 1, []))
        self.jmenos1.append(Jmeno("Václav", 1, []))
        self.jmenos1.append(Jmeno("Valentýn", 1, []))
        self.jmenos1.append(Jmeno("Vavřinec", 1, []))
        self.jmenos1.append(Jmeno("Vendelín", 1, []))
        self.jmenos1.append(Jmeno("Věroslav", 1, []))
        self.jmenos1.append(Jmeno("Vilém", 1, []))
        self.jmenos1.append(Jmeno("Vít", 1, []))
        self.jmenos1.append(Jmeno("Vítek", 1, []))
        self.jmenos1.append(Jmeno("Vítězslav", 1, []))
        self.jmenos1.append(Jmeno("Vladan", 1, []))
        self.jmenos1.append(Jmeno("Vladimír", 1, ["Laďa"]))
        self.jmenos1.append(Jmeno("Vladislav", 1, []))
        self.jmenos1.append(Jmeno("Vlastimil", 1, []))
        self.jmenos1.append(Jmeno("Vojtěch", 1, []))
        self.jmenos1.append(Jmeno("Vratislav", 1, []))
        self.jmenos1.append(Jmeno("Waldemar", 1, []))
        self.jmenos1.append(Jmeno("Zbyněk", 1, []))
        self.jmenos1.append(Jmeno("Zbyšek", 1, []))
        self.jmenos1.append(Jmeno("Zdeněk", 1, []))
        self.jmenos1.append(Jmeno("Zikmund", 1, []))

        #
        self.jmenos2.append(Jmeno("Adéla", 2, []))
        self.jmenos2.append(Jmeno("Alena", 2, []))
        self.jmenos2.append(Jmeno("Alice", 2, []))
        self.jmenos2.append(Jmeno("Anežka", 2, []))
        self.jmenos2.append(Jmeno("Barbora", 2, []))
        self.jmenos2.append(Jmeno("Blanka", 2, []))
        self.jmenos2.append(Jmeno("Božena", 2, []))
        self.jmenos2.append(Jmeno("Dagmar", 2, []))
        self.jmenos2.append(Jmeno("Daniela", 2, []))
        self.jmenos2.append(Jmeno("Dita", 2, []))
        self.jmenos2.append(Jmeno("Dominika", 2, []))
        self.jmenos2.append(Jmeno("Drahomíra", 2, []))
        self.jmenos2.append(Jmeno("Edita", 2, []))
        self.jmenos2.append(Jmeno("Eliška", 2, []))
        self.jmenos2.append(Jmeno("Eliška", 2, []))
        self.jmenos2.append(Jmeno("Eva", 2, []))
        self.jmenos2.append(Jmeno("Gabriela", 2, []))
        self.jmenos2.append(Jmeno("Hana", 2, []))
        self.jmenos2.append(Jmeno("Helena", 2, []))
        self.jmenos2.append(Jmeno("Ilona", 2, []))
        self.jmenos2.append(Jmeno("Ingrid", 2, []))
        self.jmenos2.append(Jmeno("Ivana", 2, []))
        self.jmenos2.append(Jmeno("Iveta", 2, []))
        self.jmenos2.append(Jmeno("Jana", 2, []))
        self.jmenos2.append(Jmeno("Jarmila", 2, []))
        self.jmenos2.append(Jmeno("Jolana", 2, []))
        self.jmenos2.append(Jmeno("Kamila", 2, []))
        self.jmenos2.append(Jmeno("Karolína", 2, []))
        self.jmenos2.append(Jmeno("Kateřina", 2, []))
        self.jmenos2.append(Jmeno("Klára", 2, []))
        self.jmenos2.append(Jmeno("Kristýny", 2, []))
        self.jmenos2.append(Jmeno("Květa", 2, []))
        self.jmenos2.append(Jmeno("Lenka", 2, []))
        self.jmenos2.append(Jmeno("Leona", 2, []))
        self.jmenos2.append(Jmeno("Lucie", 2, []))
        self.jmenos2.append(Jmeno("Magda", 2, []))
        self.jmenos2.append(Jmeno("Marie", 2, ["Maruška", "Majka", "Mary"]))
        self.jmenos2.append(Jmeno("Michaela", 2, []))
        self.jmenos2.append(Jmeno("Monika", 2, []))
        self.jmenos2.append(Jmeno("Olga", 2, []))
        self.jmenos2.append(Jmeno("Patricie", 2, []))
        self.jmenos2.append(Jmeno("Pavlína", 2, []))
        self.jmenos2.append(Jmeno("Petra", 2, []))
        self.jmenos2.append(Jmeno("Radana", 2, []))
        self.jmenos2.append(Jmeno("Radka", 2, []))
        self.jmenos2.append(Jmeno("Rebeka", 2, []))
        self.jmenos2.append(Jmeno("Renata", 2, []))
        self.jmenos2.append(Jmeno("Romana", 2, []))
        self.jmenos2.append(Jmeno("Růžena", 2, []))
        self.jmenos2.append(Jmeno("Sára", 2, []))
        self.jmenos2.append(Jmeno("Silvie", 2, []))
        self.jmenos2.append(Jmeno("Soňa", 2, []))
        self.jmenos2.append(Jmeno("Světlana", 2, []))
        self.jmenos2.append(Jmeno("Šárka", 2, []))
        self.jmenos2.append(Jmeno("Štěpánka", 2, []))
        self.jmenos2.append(Jmeno("Věra", 2, []))
        self.jmenos2.append(Jmeno("Veronika", 2, []))
        self.jmenos2.append(Jmeno("Vladimíra", 2, []))
        self.jmenos2.append(Jmeno("Yvona", 2, []))
        self.jmenos2.append(Jmeno("Zdenka", 2, []))
        self.jmenos2.append(Jmeno("Zita", 2, []))
        self.jmenos2.append(Jmeno("Zuzana", 2, []))
        self.jmenos2.append(Jmeno("Žaneta", 2, []))



class Okres:
    """Objekt pro zapouzdření informací o okrese jako územním celku.."""
    def __init__(self, nazev, oznaceni, mesto):
        self.nazev = nazev
        self.oznaceni = oznaceni
        self.mesto = mesto

    def IsEqual(self, okres):
        """ Porovnáme dva okresy a pokud jsou schodné vracíme True.. """
        if self.nazev == okres.nazev and self.oznaceni == okres.oznaceni and self.mesto == okres.mesto:
            return True
        return False



from setuptools import setup

with open('README') as f:
    long_description = ''.join(f.readlines())

setup(
    name='pyranda',
    version='0.0.20',
    description='Generate random data of common czech names',
    long_description=long_description,
    author='Radomír Ludva',
    author_email='rludva@radmi.cz',
    license='Public Domain',
    url='https://github.com/rludva/pyranda',
    packages=['pyranda', 'pyranda/demo'],
    classifiers=[
        'Intended Audience :: Developers',
        'License :: Public Domain',
        'Natural Language :: Czech',
        'Operating System :: POSIX :: Linux',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Topic :: Software Development :: Libraries',
        ],
    zip_safe=False,
    entry_points={
        'console_scripts': [
            'pyranda  = pyranda.app:main',
        ],
    },
    setup_requires=['pytest-runner',],
    tests_require=['pytest',],
)
